Insert measurement likelihood (without regression) code chunks into .bug model file
insert_bugfile_chunk_noreg_meas(
k_subclass,
Mobs,
prior,
cause_list,
use_measurements = "BrS",
ppd = NULL,
use_jags = FALSE
)a long character string to be inserted into .bug model file as measurement likelihood
the number of subclasses for the slices that require conditional dependence modeling (only applicable to BrS data); its length is of the same value as the number of BrS slices.
measurement data in the form of data_nplcm
prior specification from model_options
a list of latent status names (crucial for building templates;
see make_template())
"BrS", or "SS"
Default is NULL; set to TRUE for posterior predictive checking
Default is FALSE; set to TRUE if want to use JAGS for model fitting.
It is used in write_model_NoReg for constructing a .bug file along with specification of latent status distribution (insert_bugfile_chunk_noreg_etiology)