Insert measurement likelihood (with regression) code chunks into .bug model file
insert_bugfile_chunk_reg_nonest_meas(
Mobs,
prior,
cause_list,
FPR_formula,
use_measurements = "BrS",
ppd = NULL,
use_jags = FALSE
)A long character string to be inserted into .bug model file as measurement likelihood
Measurement data in the form of data_nplcm
Prior specification from model_options
A list of latent status names (crucial for building templates;
see make_template())
A list of FPR regression formula; check model_options$likelihood$FPR_formula
"BrS", or "SS"
Default is NULL; set to TRUE for posterior predictive checking
Default is FALSE; set to TRUE if want to use JAGS for model fitting.
It is used in write_model_Reg_NoNest for constructing a .bug file along with specification of latent status regression (insert_bugfile_chunk_reg_etiology)