Learn R Programming

baker (version 1.0.4)

is_length_all_one: check if a list has elements all of length one

Description

check if a list has elements all of length one

Usage

is_length_all_one(x)

Value

TRUE or FALSE

Arguments

x

a list

Examples

Run this code
l = list(a = 5, b = 1:2)
is_length_all_one(l) # FALSE
l = list(a = 5, b = 1)
is_length_all_one(l) # TRUE

Run the code above in your browser using DataLab