set_prior_tpr_BrS_NoNest is for for conditional independence models.
We currently also use it for conditional dependence model: subclass TPRs
are independently assigned a beta prior. Ongoing work will enable specifying
priors for the marginal TPR, i.e. TPRs for a disease class, not for the
finer subclass.
set_prior_tpr_BrS_NoNest(slice, model_options, data_nplcm)Parameters for the BrS dta TPR priors. It is a list of two lists (alpha and beta). Alpha and beta are of the same length, the number of BrS measurement slices. Each element of the alpha (beta) list is a numeric vector for alpha (beta) parameters as in BETA distribution.
The BrS measurement slice under consideration.
See nplcm() function.
See assign_model() function.
Other prior specification functions:
overall_uniform(),
set_prior_tpr_SS()